from distutils.core import setup
setup(
  name = 'access_dict_by_dot',
  packages = ['access_dict_by_dot'],
  version = '0.0.1',
  license='MIT',
  description = 'Using this packages we can access dictionary values using dot operator',
  author = 'Indrajeet Singh',
  author_email = 'indrajeetsinghmaan@gmail.com',
  url = 'https://github.com/ismaan1998/access_dict_by_dot/',
  download_url = 'https://github.com/ismaan1998/access_dict_by_dot/releases/tag/0.0.1',
  keywords = ['dictionary', 'dot', 'access'],

  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
  ],
)